ardt.preprocessors.ChannelSelector.ChannelSelector
==================================================

.. currentmodule:: ardt.preprocessors.ChannelSelector

.. autoclass:: ChannelSelector

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ChannelSelector.__init__
      ~ChannelSelector.process_signal
      ~ChannelSelector.resolve
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ChannelSelector.context
   
   